==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_sv_SE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv_SE" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Enheten är upptagen</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Mejla sensaste video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Mejla en eller flera valda video</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Skicka</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Du hittar videon som bilaga</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Välj en eller flera filer</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Ram</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Enheten är upptagen</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskärm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fönster</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Förstoringsglas</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ljud</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Spela inte in muspekaren</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videosökväg</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Spelare</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen är förminskad när inspelningen startas</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spela</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Skicka</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Inspelningstid</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Storlek in kb</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Inspelning skärmstorlek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Inställningar fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Öppen katalog</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedräkning</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Spela förra videon</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Skicka video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Mejla en eller flera valda video</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktuella antal bilder per sekund</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_sv_SE.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv_SE" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Enheten är upptagen</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>okänd</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>utrustning</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>används av</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Mejla sensaste video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Mejla en eller flera valda video</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Skicka</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>avboka</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Installera en videospelare</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Du hittar videon som bilaga</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Välj en eller flera filer</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Ram</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Om Visa i fullskärmsläge</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Högerklicka på Menu</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>anpassad</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Enheten är upptagen</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>utrustning</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>används av</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>okänd</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Fullskärm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fönster</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Område</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Förstoringsglas</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ljud</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Spela inte in muspekaren</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videosökväg</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Spelare</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen är förminskad när inspelningen startas</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spela</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Skicka</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Inspelningstid</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Storlek in kb</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Inspelning skärmstorlek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Inställningar fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Öppen katalog</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Nedräkning</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Spela förra videon</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Skicka video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Mejla en eller flera valda video</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Aktuella antal bilder per sekund</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Hemsida</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Stöd</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Utvecklare</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Ramar</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>donation</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>översättning</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>källkod</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Visa i Systray</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Ny version tillgänglig</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Välj Webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>speglad</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>skärm</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>alla skärmar</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Utvecklare Hemsida</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>inspelningsapparat</translation>
    </message>
    <message>
        <source>Select recorder</source>
        <translation>Välj inspelningsapparat</translation>
    </message>
    <message>
        <source>Hide window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lossless</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
